@@ -257,9 +257,9 @@ QVariant ScriptableLiveConnectExtension::callFunctionReference(ScriptableExtensi
     QStringList qargs;
     // Convert args to strings for LC use.
     qargs.reserve(a.size());
-    for (int i = 0; i < a.size(); ++i) {
+    for (const auto &arg : a) {
         bool ok;
-        qargs.append(toLC(a[i], &ok));
+        qargs.append(toLC(arg, &ok));
         if (!ok) {
             return unimplemented();
         }
@@ -414,8 +414,7 @@ void ScriptableLiveConnectExtension::liveConnectEvent(const unsigned long, const
 
     // Compute a string to evaluate. We need to escape a lot of stuff
     // since we're composing a bunch of strings into one.
-    QString script;
-    script.sprintf("%s(", event.toLatin1().constData());
+    QString script = event + QLatin1Char('(');
 
     LiveConnectExtension::ArgList::const_iterator i = args.begin();
     const LiveConnectExtension::ArgList::const_iterator argsBegin = i;
